@@ -1,5 +1,5 @@
 /* jSSC (Java Simple Serial Connector) - serial port communication library.
- * © Alexey Sokolov (scream3r), 2010-2013.
+ * © Alexey Sokolov (scream3r), 2010-2014.
  *
  * This file is part of jSSC.
  *
@@ -48,6 +48,12 @@
 
 //#include <iostream> //-lCstd use for Solaris linker
 
+/*
+ * Get native library version
+ */
+JNIEXPORT jstring JNICALL Java_jssc_SerialNativeInterface_getNativeLibraryVersion(JNIEnv *env, jobject object) {
+    return env->NewStringUTF(jSSC_NATIVE_LIB_VERSION);
+}
 
 /* OK */
 /*
@@ -72,6 +78,7 @@ JNIEXPORT jlong JNICALL Java_jssc_SerialNativeInterface_openPort(JNIEnv *env, jo
             fcntl(hComm, F_SETFL, flags);
         }
         else {
+            close(hComm);//since 2.7.0
             hComm = jssc_SerialNativeInterface_ERR_INCORRECT_SERIAL_PORT;//-4;
         }
         delete settings;
