@@ -1,5 +1,5 @@
 /* jSSC (Java Simple Serial Connector) - serial port communication library.
- * © Alexey Sokolov (scream3r), 2010-2013.
+ * © Alexey Sokolov (scream3r), 2010-2014.
  *
  * This file is part of jSSC.
  *
@@ -24,7 +24,9 @@
  */
 package jssc;
 
+import java.io.UnsupportedEncodingException;
 import java.lang.reflect.Method;
+import java.nio.charset.Charset;
 
 /**
  *
@@ -375,6 +377,20 @@ public class SerialPort {
         return writeBytes(string.getBytes());
     }
 
+    /**
+     * Write String to port
+     *
+     * @return If the operation is successfully completed, the method returns true, otherwise false
+     *
+     * @throws SerialPortException
+     *
+     * @since 2.8.0
+     */
+    public boolean writeString(String string, String charsetName) throws SerialPortException, UnsupportedEncodingException {
+        checkPortOpened("writeString()");
+        return writeBytes(string.getBytes(charsetName));
+    }
+
     /**
      * Write int value (in range from 0 to 255 (0x00 - 0xFF)) to port
      *
